summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/formwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/formwindow.cpp')
-rw-r--r--kdevdesigner/designer/formwindow.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/kdevdesigner/designer/formwindow.cpp b/kdevdesigner/designer/formwindow.cpp
index 7da756de..77fb2c3f 100644
--- a/kdevdesigner/designer/formwindow.cpp
+++ b/kdevdesigner/designer/formwindow.cpp
@@ -108,7 +108,7 @@ static void restoreCursors( TQWidget *start, FormWindow *fw )
}
}
-#if defined(TQ_WS_WIN32) // #### needed for the workaround for tqrepaint problem on windows
+#if defined(TQ_WS_WIN32) // #### needed for the workaround for repaint problem on windows
#include <tqt_windows.h>
static void flickerfree_update( TQWidget *w )
{
@@ -383,13 +383,13 @@ void FormWindow::insertWidget()
"properties as well as signals and slots to integrate custom widgets into "
"<i>TQt Designer</i>, and provide a pixmap which will be used to represent "
"the widget on the form.</p>")
- .tqarg(WidgetDatabase::toolTip( id )) );
- TQToolTip::add( w, i18n("A %1 (custom widget)").tqarg(WidgetDatabase::toolTip( id )) );
+ .arg(WidgetDatabase::toolTip( id )) );
+ TQToolTip::add( w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
} else {
TQString tt = WidgetDatabase::toolTip( id );
TQString wt = WidgetDatabase::whatsThis( id );
if ( !wt.isEmpty() && !tt.isEmpty() )
- TQWhatsThis::add( w, TQString("<b>A %1</b><p>%2</p>").tqarg( tt ).tqarg( wt ) );
+ TQWhatsThis::add( w, TQString("<b>A %1</b><p>%2</p>").arg( tt ).arg( wt ) );
}
TQString s = w->name();
@@ -463,13 +463,13 @@ void FormWindow::insertWidget()
else
setCursorToAll( CrossCursor, w );
- InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).tqarg( w->name() ), this, w, r );
+ InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).arg( w->name() ), this, w, r );
TQPtrList<Command> commands;
commands.append( mv );
commands.append( cmd );
- MacroCommand *mc = new MacroCommand( i18n( "Insert %1" ).tqarg( w->name() ), this, commands );
+ MacroCommand *mc = new MacroCommand( i18n( "Insert %1" ).arg( w->name() ), this, commands );
commandHistory()->addCommand( mc );
mc->execute();
}
@@ -479,7 +479,7 @@ void FormWindow::insertWidget()
else
setCursorToAll( CrossCursor, w );
- InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).tqarg( w->name() ), this, w, r );
+ InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).arg( w->name() ), this, w, r );
commandHistory()->addCommand( cmd );
cmd->execute();
}
@@ -510,13 +510,13 @@ void FormWindow::insertWidget( TQWidget *w, bool checkName )
"properties as well as signals and slots to integrate custom widgets into "
"<i>TQt Designer</i>, and provide a pixmap which will be used to represent "
"the widget on the form.</p>")
- .tqarg(WidgetDatabase::toolTip( id )) );
- TQToolTip::add( w, i18n("A %1 (custom widget)").tqarg(WidgetDatabase::toolTip( id )) );
+ .arg(WidgetDatabase::toolTip( id )) );
+ TQToolTip::add( w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
} else {
TQString tt = WidgetDatabase::toolTip( id );
TQString wt = WidgetDatabase::whatsThis( id );
if ( !wt.isEmpty() && !tt.isEmpty() )
- TQWhatsThis::add( w, TQString("<b>A %1</b><p>%2</p>").tqarg( tt ).tqarg( wt ) );
+ TQWhatsThis::add( w, TQString("<b>A %1</b><p>%2</p>").arg( tt ).arg( wt ) );
}
restoreCursors( w, this );
@@ -622,7 +622,7 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
( WidgetFactory::layoutType( w->parentWidget()) != WidgetFactory::NoLayout || !insertedWidgets.find(w) ) )
w = w->parentWidget();
- if ( e->button() == Qt::LeftButton ) { // left button: store original tqgeometry and more as the widget might start moving
+ if ( e->button() == Qt::LeftButton ) { // left button: store original geometry and more as the widget might start moving
widgetPressed = TRUE;
widgetGeom = TQRect( w->pos(), w->size() );
oldPressPos = w->mapFromGlobal( e->globalPos() );
@@ -660,9 +660,9 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
break;
clearSelection( FALSE );
validForBuddy = TRUE;
- mainWindow()->statusMessage( i18n( "Set buddy for '%1' to..." ).tqarg( w->name() ) );
+ mainWindow()->statusMessage( i18n( "Set buddy for '%1' to..." ).arg( w->name() ) );
} else {
- mainWindow()->statusMessage( i18n( "Connect '%1' with..." ).tqarg( w->name() ) );
+ mainWindow()->statusMessage( i18n( "Connect '%1' with..." ).arg( w->name() ) );
}
saveBackground();
startPos = mapFromGlobal( e->globalPos() );
@@ -837,7 +837,7 @@ void FormWindow::handleMouseMove( TQMouseEvent *e, TQWidget *w )
// finally move the selected widgets and show/update preview label
moveSelectedWidgets( x - p.x(), y - p.y() );
- sizePreviewLabel->setText( i18n( "%1/%2" ).tqarg( w->pos().x() ).tqarg( w->pos().y() ) );
+ sizePreviewLabel->setText( i18n( "%1/%2" ).arg( w->pos().x() ).arg( w->pos().y() ) );
sizePreviewLabel->adjustSize();
TQRect lg( mapFromGlobal( e->globalPos() ) + TQPoint( 16, 16 ), sizePreviewLabel->size() );
checkPreviewGeometry( lg );
@@ -871,7 +871,7 @@ void FormWindow::handleMouseMove( TQMouseEvent *e, TQWidget *w )
if ( newendWidget &&
( isMainContainer( TQT_TQOBJECT(newendWidget) ) || insertedWidgets.find( newendWidget ) ) && !isCentralWidget( TQT_TQOBJECT(newendWidget) ) )
endWidget = newendWidget;
- mainWindow()->statusMessage( i18n( "Connect '%1' to '%2'" ).tqarg( startWidget->name() ).
+ mainWindow()->statusMessage( i18n( "Connect '%1' to '%2'" ).arg( startWidget->name() ).
arg( endWidget->name() ) );
currentPos = mapFromGlobal( e->globalPos() );
tqApp->processEvents();
@@ -899,10 +899,10 @@ void FormWindow::handleMouseMove( TQMouseEvent *e, TQWidget *w )
else if ( insertedWidgets.find( newendWidget ) && !isCentralWidget( TQT_TQOBJECT(newendWidget) ) )
endWidget = newendWidget;
if ( endWidget )
- mainWindow()->statusMessage( i18n( "Set buddy '%1' to '%2'" ).tqarg( startWidget->name() ).
+ mainWindow()->statusMessage( i18n( "Set buddy '%1' to '%2'" ).arg( startWidget->name() ).
arg( endWidget->name() ) );
else
- mainWindow()->statusMessage( i18n( "Set buddy '%1' to ..." ).tqarg( startWidget->name() ) );
+ mainWindow()->statusMessage( i18n( "Set buddy '%1' to ..." ).arg( startWidget->name() ) );
currentPos = mapFromGlobal( e->globalPos() );
tqApp->processEvents();
if ( drawRecRect && oldendWidget )
@@ -1044,7 +1044,7 @@ void FormWindow::handleMouseRelease( TQMouseEvent *e, TQWidget *w )
TQString oldBuddy = startWidget->property( "buddy" ).toString();
if ( oldBuddy.isNull() )
oldBuddy = "";
- SetPropertyCommand *cmd = new SetPropertyCommand( i18n( "Set Buddy for %1" ).tqarg( startWidget->name() ),
+ SetPropertyCommand *cmd = new SetPropertyCommand( i18n( "Set Buddy for %1" ).arg( startWidget->name() ),
this, TQT_TQOBJECT(startWidget), mainWindow()->propertyeditor(),
"buddy", startWidget->property( "buddy" ),
endWidget->name(), endWidget->name(),
@@ -1327,7 +1327,7 @@ void FormWindow::continueRectDraw( const TQPoint &p, const TQPoint &global, TQWi
if ( currRect == r ) {
TQString t = i18n( "%1/%2" );
- t = t.tqarg( r.width() - 1 ).tqarg( r.height() - 1 );
+ t = t.arg( r.width() - 1 ).arg( r.height() - 1 );
drawSizePreview( pos, t );
return;
}
@@ -1339,7 +1339,7 @@ void FormWindow::continueRectDraw( const TQPoint &p, const TQPoint &global, TQWi
currRect = r;
if ( t == Insert ) {
TQString t = i18n( "%1/%2" );
- t = t.tqarg( r.width() - 1 ).tqarg( r.height() - 1 );
+ t = t.arg( r.width() - 1 ).arg( r.height() - 1 );
drawSizePreview( pos, t );
}
unclippedPainter->setClipRegion( TQRegion( rect() ).subtract( TQRect( sizePreviewPos, sizePreviewPixmap.size() ) ) );
@@ -1502,13 +1502,13 @@ void FormWindow::editAdjustSize()
TQPtrList<Command> commands;
TQWidgetList widgets = selectedWidgets();
if ( widgets.isEmpty() ) {
- TQRect oldr = tqgeometry();
+ TQRect oldr = geometry();
mainContainer()->adjustSize();
resize( mainContainer()->size() );
// check whether our own size constraint hit us
if ( size() != mainContainer()->size() )
mainContainer()->resize( size() );
- TQRect nr = tqgeometry();
+ TQRect nr = geometry();
if ( oldr != nr ) {
ResizeCommand *cmd = new ResizeCommand( i18n( "Adjust Size" ), this, this, oldr, nr );
commandHistory()->addCommand( cmd );
@@ -1518,9 +1518,9 @@ void FormWindow::editAdjustSize()
for ( TQWidget* w = widgets.first(); w; w = widgets.next() ) {
if ( w->parentWidget() && WidgetFactory::layoutType( w->parentWidget() ) != WidgetFactory::NoLayout )
continue;
- TQRect oldr = w->tqgeometry();
+ TQRect oldr = w->geometry();
w->adjustSize();
- TQRect nr = w->tqgeometry();
+ TQRect nr = w->geometry();
if ( oldr != nr )
commands.append( new ResizeCommand( i18n("Adjust Size"), this, w, oldr, nr ) );
}
@@ -1759,7 +1759,7 @@ void FormWindow::currentToolChanged()
emitShowProperties( TQT_TQOBJECT(mainContainer()) );
break;
default:
- mainWindow()->statusMessage( i18n( "Click on the form to insert a %1..." ).tqarg( WidgetDatabase::toolTip( currTool ).lower() ) );
+ mainWindow()->statusMessage( i18n( "Click on the form to insert a %1..." ).arg( WidgetDatabase::toolTip( currTool ).lower() ) );
setCursorToAll( CrossCursor, this );
if ( mainWindow()->formWindow() == this )
emitShowProperties( TQT_TQOBJECT(mainContainer()) );
@@ -1832,7 +1832,7 @@ bool FormWindow::checkCustomWidgets()
if ( !missingCustomWidgets.isEmpty() ) {
TQString txt = i18n( "The following custom widgets are used in '%1',\n"
- "but are not known to TQt Designer:\n" ).tqarg( name() );
+ "but are not known to TQt Designer:\n" ).arg( name() );
for ( TQStringList::Iterator sit = missingCustomWidgets.begin(); sit != missingCustomWidgets.end(); ++sit )
txt += " " + *sit + "\n";
txt += i18n( "If you save this form and generate code for it using uic, \n"
@@ -1935,7 +1935,7 @@ void FormWindow::checkAccels()
ok = FALSE;
switch ( TQMessageBox::information( mainWindow(), i18n( "Check Accelerators" ),
i18n( "Accelerator '%1' is used once.", "Accelerator '%1' is used %n times.", (*it).count()
- ).tqarg( it.key().upper() ),
+ ).arg( it.key().upper() ),
i18n( "&Select" ),
i18n( "&Cancel" ), TQString(), 2 ) ) {
case 0: // select